require 'rails_helper'

RSpec.describe ::User, type: :model do
  describe 'Lessor association' do
    let!(:entity1) { create(:entity) }
    let!(:user_lessor) { create(:user, first_name: 'user_lessor', group_ids:[entity1.manager_group_id]) }
    let!(:user_lessor_associated) { create(:user) }
    let!(:user_not_associated) { create(:user) }
    let!(:lessor) { create(:lessor, user_id: user_lessor.id) }
    
    it 'can associate lessor and user' do
      user_lessor_associated.lessor = lessor
      user_lessor_associated.save
      user_lessor_associated.reload
      user_lessor.reload
      expect(user_lessor.lessor).to eq(lessor)
      expect(user_lessor_associated.lessor).to eq(lessor)
    end

    it 'should return true or false dependant of lessor association' do
      user_lessor.reload
      user_not_associated.reload
      expect(user_lessor.has_lessor?).to be(true)
      expect(user_not_associated.has_lessor?).to be(false)
    end

    it 'create user_right' do
      expect(Hermes::UserRight.all.count).to be(1)
      user_lessor.group_ids = []
      user_lessor.save
      expect(Hermes::UserRight.all.count).to be(0)
    end
  end
end
